#!/usr/bin/env python

"""
Parse combined sponge data XML files.

Usage:

   > python parse.py path/to/xml/file
   > python parse.py -t
   > python parse.py --test

Test silent import.

>>> import parse
"""

__author__ = "Chris Calloway"
__email__ = "cbc@chriscalloway.org"
__copyright__ = "Copyright 2010 UNC-CH Department of Marine Science"
__license__ = "GPL2"

import sys
import os
import glob
import doctest
import unittest
from StringIO import StringIO

USAGE = "\n".join(__doc__.splitlines()[3:8])
TEST_PATH = "tests/parse"


def _test():
    """
    Run doctests as unittest suite.

    Test silent import

    >>> from parse import _test
    """

    suite = []
    suite.append(doctest.DocTestSuite())
    suite = unittest.TestSuite(suite)
    unittest.TextTestRunner().run(suite)

    return


def doc_path():
    """
    Return the XML document file path from the command line.

    Supply too few arguments on command line.

    >>> save_stdout = sys.stdout
    >>> temp_stdout = StringIO()
    >>> sys.stdout = temp_stdout
    >>> sys.argv = []
    >>> _doc_path = doc_path()
    >>> sys.stdout = save_stdout
    >>> USAGE == temp_stdout.getvalue()[:-1]
    True

    Supply too many arguments on the command line.

    >>> save_stdout = sys.stdout
    >>> temp_stdout = StringIO()
    >>> sys.stdout = temp_stdout
    >>> sys.argv = ["", "", "",]
    >>> _doc_path = doc_path()
    >>> sys.stdout = save_stdout
    >>> USAGE == temp_stdout.getvalue()[:-1]
    True

    Supply non-file argument.

    >>> save_stdout = sys.stdout
    >>> temp_stdout = StringIO()
    >>> sys.stdout = temp_stdout
    >>> _doc_path = os.path.join(
    ...                 os.path.dirname(
    ...                     os.path.abspath(__file__)),
    ...                 TEST_PATH)
    >>> sys.argv = ["", _doc_path]
    >>> _doc_path = doc_path()
    >>> sys.stdout = save_stdout
    >>> USAGE == temp_stdout.getvalue()[:-1]
    True

    Supply nonexistent file argument.

    >>> save_stdout = sys.stdout
    >>> temp_stdout = StringIO()
    >>> sys.stdout = temp_stdout
    >>> _doc_path = os.path.join(
    ...                 os.path.dirname(
    ...                     os.path.abspath(__file__)),
    ...                 TEST_PATH, "xxxxx")
    >>> sys.argv = ["", _doc_path]
    >>> _doc_path = doc_path()
    >>> sys.stdout = save_stdout
    >>> USAGE == temp_stdout.getvalue()[:-1]
    True

    Supply valid XML document path argument.

    >>> _doc_path = os.path.join(
    ...                 os.path.dirname(
    ...                     os.path.abspath(__file__)),
    ...                 TEST_PATH, "xml","*","*.xml")
    >>> _doc_path = glob.glob(_doc_path)[0]
    >>> sys.argv = ["", _doc_path]
    >>> _doc_path == doc_path()
    True
    """

    path = None
    try:
        if len(sys.argv) == 2:
            if sys.argv[1] == "-t" or sys.argv[1] == "--test":
                _test()
            else:
                path = sys.argv[1]
                if not os.path.exists(path):
                    raise IOError(path + \
                                  " does not exist.")
                elif not os.path.isfile(path):
                    raise IOError(path + \
                                  " is not a file.")
        else:
            raise IOError("Incorrect number of arguments supplied.")
    except IOError:
        print USAGE
    return path


def _main():
    """
    Run module as script.

    Test silent import.

    >>> from parse import _main
    """

    _doc_path = doc_path()
    if _doc_path:
        print _doc_path

    return

if __name__ == "__main__":
    _main()
